@@ -2,12 +2,16 @@ package awsutil
 
 import (
 	"bytes"
+	"errors"
 	"net/http"
 	"net/http/httputil"
 	"regexp"
 
-	"github.com/rebuy-de/aws-nuke/v2/pkg/util"
-	log "github.com/sirupsen/logrus"
+	"github.com/sirupsen/logrus"
+
+	"github.com/aws/aws-sdk-go/aws/awserr"
+
+	"github.com/ekristen/libnuke/pkg/utils"
 )
 
 var (
@@ -21,26 +25,34 @@ func HideSecureHeaders(dump []byte) []byte {
 func DumpRequest(r *http.Request) string {
 	dump, err := httputil.DumpRequest(r, true)
 	if err != nil {
-		log.WithField("Error", err).
-			Warnf("failed to dump HTTP request")
+		logrus.WithField("Error", err).Warnf("failed to dump HTTP request")
 		return ""
 	}
 
 	dump = bytes.TrimSpace(dump)
 	dump = HideSecureHeaders(dump)
-	dump = util.IndentBytes(dump, []byte("    > "))
+	dump = utils.IndentBytes(dump, []byte("    > "))
 	return string(dump)
 }
 
 func DumpResponse(r *http.Response) string {
 	dump, err := httputil.DumpResponse(r, true)
 	if err != nil {
-		log.WithField("Error", err).
-			Warnf("failed to dump HTTP response")
+		logrus.WithField("Error", err).Warnf("failed to dump HTTP response")
 		return ""
 	}
 
 	dump = bytes.TrimSpace(dump)
-	dump = util.IndentBytes(dump, []byte("    < "))
+	dump = utils.IndentBytes(dump, []byte("    < "))
 	return string(dump)
 }
+
+func IsAWSError(err error, code string) bool {
+	var aerr awserr.Error
+	ok := errors.As(err, &aerr)
+	if !ok {
+		return false
+	}
+
+	return aerr.Code() == code
+}
