@@ -1,25 +1,37 @@
 package resources
 
 import (
+	"context"
 	"fmt"
 
-	"github.com/aws/aws-sdk-go/aws/session"
+	"github.com/gotidy/ptr"
+
 	"github.com/aws/aws-sdk-go/service/appstream"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppStreamFleetState struct {
-	svc   *appstream.AppStream
-	name  *string
-	state *string
-}
+const AppStreamFleetStateResource = "AppStreamFleetState"
 
 func init() {
-	register("AppStreamFleetState", ListAppStreamFleetStates)
+	registry.Register(&registry.Registration{
+		Name:     AppStreamFleetStateResource,
+		Scope:    nuke.Account,
+		Resource: &AppStreamFleetState{},
+		Lister:   &AppStreamFleetStateLister{},
+	})
 }
 
-func ListAppStreamFleetStates(sess *session.Session) ([]Resource, error) {
-	svc := appstream.New(sess)
-	resources := []Resource{}
+type AppStreamFleetStateLister struct{}
+
+func (l *AppStreamFleetStateLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appstream.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &appstream.DescribeFleetsInput{}
 
@@ -47,8 +59,13 @@ func ListAppStreamFleetStates(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppStreamFleetState) Remove() error {
+type AppStreamFleetState struct {
+	svc   *appstream.AppStream
+	name  *string
+	state *string
+}
 
+func (f *AppStreamFleetState) Remove(_ context.Context) error {
 	_, err := f.svc.StopFleet(&appstream.StopFleetInput{
 		Name: f.name,
 	})
@@ -61,9 +78,9 @@ func (f *AppStreamFleetState) String() string {
 }
 
 func (f *AppStreamFleetState) Filter() error {
-	if *f.state == "STOPPED" {
+	if ptr.ToString(f.state) == appstream.FleetStateStopped {
 		return fmt.Errorf("already stopped")
-	} else if *f.state == "DELETING" {
+	} else if ptr.ToString(f.state) == "DELETING" {
 		return fmt.Errorf("already being deleted")
 	}
 
