@@ -1,21 +1,36 @@
 package resources
 
 import (
-	"time"
+	"context"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/autoscaling"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
+const AutoScalingGroupResource = "AutoScalingGroup"
+
 func init() {
-	register("AutoScalingGroup", ListAutoscalingGroups)
+	registry.Register(&registry.Registration{
+		Name:     AutoScalingGroupResource,
+		Scope:    nuke.Account,
+		Resource: &AutoScalingGroup{},
+		Lister:   &AutoScalingGroupLister{},
+	})
 }
 
-func ListAutoscalingGroups(s *session.Session) ([]Resource, error) {
-	svc := autoscaling.New(s)
-	resources := make([]Resource, 0)
+type AutoScalingGroupLister struct{}
+
+func (l *AutoScalingGroupLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := autoscaling.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &autoscaling.DescribeAutoScalingGroupsInput{}
 	err := svc.DescribeAutoScalingGroupsPages(params,
@@ -29,6 +44,7 @@ func ListAutoscalingGroups(s *session.Session) ([]Resource, error) {
 			}
 			return !lastPage
 		})
+
 	if err != nil {
 		return nil, err
 	}
@@ -42,7 +58,7 @@ type AutoScalingGroup struct {
 	tags  []*autoscaling.TagDescription
 }
 
-func (asg *AutoScalingGroup) Remove() error {
+func (asg *AutoScalingGroup) Remove(_ context.Context) error {
 	params := &autoscaling.DeleteAutoScalingGroupInput{
 		AutoScalingGroupName: asg.group.AutoScalingGroupName,
 		ForceDelete:          aws.Bool(true),
@@ -66,7 +82,7 @@ func (asg *AutoScalingGroup) Properties() types.Properties {
 		properties.SetTag(tag.Key, tag.Value)
 	}
 
-	properties.Set("CreatedTime", asg.group.CreatedTime.Format(time.RFC3339))
+	properties.Set("CreatedTime", asg.group.CreatedTime)
 	properties.Set("Name", asg.group.AutoScalingGroupName)
 
 	return properties
