@@ -1,24 +1,35 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/xray"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type XRayGroup struct {
-	svc       *xray.XRay
-	groupName *string
-	groupARN  *string
-}
+const XRayGroupResource = "XRayGroup"
 
 func init() {
-	register("XRayGroup", ListXRayGroups)
+	registry.Register(&registry.Registration{
+		Name:     XRayGroupResource,
+		Scope:    nuke.Account,
+		Resource: &XRayGroup{},
+		Lister:   &XRayGroupLister{},
+	})
 }
 
-func ListXRayGroups(sess *session.Session) ([]Resource, error) {
-	svc := xray.New(sess)
-	resources := []Resource{}
+type XRayGroupLister struct{}
+
+func (l *XRayGroupLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := xray.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	// Get X-Ray Groups
 	var xrayGroups []*xray.GroupSummary
@@ -48,7 +59,13 @@ func ListXRayGroups(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *XRayGroup) Remove() error {
+type XRayGroup struct {
+	svc       *xray.XRay
+	groupName *string
+	groupARN  *string
+}
+
+func (f *XRayGroup) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteGroup(&xray.DeleteGroupInput{
 		GroupARN: f.groupARN, // Only allowed to pass GroupARN _or_ GroupName to delete request
 	})
